@@ -1,4 +1,4 @@
-# shazam package documentation and import directives
+# Shazam package documentation and import directives
 
 #' The shazam package
 #'
@@ -22,6 +22,7 @@
 #'   \item  \link{expectedMutations}:        Compute expected mutation frequencies.
 #'   \item  \link{shmulateSeq}:              Simulate mutations in a single sequence.
 #'   \item  \link{shmulateTree}:             Simulate mutations over a lineage tree.
+#'   \item  \link{setRegionBoundaries}:      Extends a region definition to include CDR3 and FWR4.
 #' }
 #' 
 #' @section  SHM targeting models:
@@ -38,8 +39,8 @@
 #' \itemize{
 #'   \item  \link{createTargetingModel}:     Build a 5-mer targeting model.
 #'   \item  \link{plotMutability}:           Plot 5-mer mutability rates.
-#'   \item  \link{HH_S5F}:                Human 5-mer SHM targeting model.
-#'   \item  \link{MK_RS5NF}:              Mouse 5-mer SHM targeting model.
+#'   \item  \link{HH_S5F}:                   Human 5-mer SHM targeting model.
+#'   \item  \link{MK_RS5NF}:                 Mouse 5-mer SHM targeting model.
 #' }
 #'
 #' @section  Quantification of selection pressure:
@@ -112,6 +113,7 @@
 #'                          isValidAASeq translateStrings gridPlot
 #'                          getMRCA getPathLengths tableEdges
 #'                          progressBar baseTheme checkColumns cpuCount
+#'                          makeChangeoClone summarizeSubtrees buildPhylipLineage
 #' @importFrom  ape         mst
 #' @importFrom  diptest     dip.test
 #' @importFrom  doParallel  registerDoParallel
@@ -122,9 +124,11 @@
 #'                          mutate summarize
 #'                          mutate_at summarize_at
 #'                          rename transmute
+#'                          left_join
 #' @importFrom  foreach     foreach %dopar% registerDoSEQ
 #' @importFrom  igraph      V E as_adjacency_matrix graph_from_data_frame
-#'                          vertex_attr set_vertex_attr
+#'                          vertex_attr set_vertex_attr 
+#'                          layout_as_tree V<-
 #' @importFrom  iterators   icount
 #' @importFrom  kedd        h.ucv
 #' @importFrom  KernSmooth  bkde
@@ -134,7 +138,6 @@
 #' @importFrom  rlang       sym syms
 #' @importFrom  scales      log2_trans log10_trans trans_breaks trans_format
 #'                          math_format percent scientific pretty_breaks
-#' @importFrom  SDMTools    wt.sd
 #' @importFrom  seqinr      c2s s2c words translate
 #' @importFrom  stats       na.omit setNames ecdf sd cor cov median mad
 #'                          approx convolve weighted.mean p.adjust
@@ -142,13 +145,23 @@
 #'                          dnorm pnorm runif dgamma pgamma uniroot na.exclude
 #'                          as.dist cutree
 #' @importFrom  stringi     stri_dup stri_flatten stri_join stri_length 
-#'                          stri_sub stri_sub<- stri_detect_regex
+#'                          stri_sub stri_sub_replace stri_detect_regex
 #'                          stri_count_boundaries stri_count_regex 
 #'                          stri_extract_all_regex stri_extract_first_regex  
 #'                          stri_replace_all_regex stri_replace_first_regex
 #' @importFrom  tidyr       gather spread
+#' @importFrom  tidyselect  all_of
 NULL
 
+# Package loading actions
+.onAttach <- function(libname, pkgname) {
+    msg <- paste("As of v1.0.0 the AIRR Rearrangement schema is now the default file format.",
+                 "A description of the standard is available at https://docs.airr-community.org.",
+                 "The legacy Change-O format is supported through arguments to each function",
+                 "that allow the input column names to be explicitly defined.",
+                 sep="\n")
+    packageStartupMessage(msg)
+}
 
 #### Sysdata ####
 
@@ -219,4 +232,5 @@ NULL
 
 # Add built-in variables to global variables environment
 utils::globalVariables(c("HH_S1F", "HKL_S1F", "MK_RS1NF",
-                         "HH_S5F", "HKL_S5F", "MK_RS5NF", "U5N"), package="shazam")
\ No newline at end of file
+                         "HH_S5F", "HKL_S5F", "MK_RS5NF", "U5N",
+                         "IMGT_V_BY_REGIONS"), package="shazam")
\ No newline at end of file
